;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Loading this file installs CG/JS.
;; Please see readme.txt for more information
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

(in-package :user)

(eval-when (compile eval load)
  (require :shell)
  (use-package :excl.shell))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; validate files

(let ((platform-file
       (directory
	(merge-pathnames
	 "PLATFORM-*"
	 (path-pathname *load-pathname*)))))
  (or platform-file
      (error "Could not find the PLATFORM file."))
  
  (when (> (length platform-file) 1)
    (error "There is more than one PLATFORM file: ~a." platform-file))
  (setq platform-file (car platform-file))
  
  (or (=~ "^PLATFORM-(.*)" (file-namestring platform-file))
      (error "Cannot parse the PLATFORM file."))
  
  (let ((expected-platform $1)
	(current-platform
	 (format nil "~a~a" (symbol-name sys::.os.) #+smp "smp" #-smp "")))
    (or (string-equal expected-platform current-platform)
	(error
	 "The current platform (~a) does not match the downloaded version (~a)."
	 current-platform expected-platform)))
  ;; We are on the correct platform, fall through...
  )

;; HTML files needed for the operation of CG/JS
;; (this variable's value is generated by build_cgjs.sh)
(defvar *html-files* '("cgjs.html" "ssl-not-found.html" "browser-not-supported.html" ))

(defvar *extra-files*)
(setq *extra-files* nil)

(dolist (file *html-files*)
  (setq file (merge-pathnames file *load-pathname*))
  (or (probe-file file)
      (error "~a does not exist." file))
  (push file *extra-files*))
;; All *html-files* exist...

;; These two are directories but the pathname is specified as
;; a file, so merging works below.
(defvar *cg2js-directory* (merge-pathnames "code.cg2js" *load-pathname*))
(defvar *idejs-directory* (merge-pathnames "code.idejs" *load-pathname*))

(dolist (d (list *cg2js-directory* *idejs-directory*))
  (or (probe-file d)
      (error "~a does not exist." d)))

;; MD5 checksums of the incoming files
;; (this variable's value is generated by build_cgjs.sh)
(defvar *checksums* 
'(
(#x18e2ce3b17a9a2055c586005041e2fdd . "./code.cg2js/cg-acache.fasl")
(#x6599f3530a612d6daee2324658ab6068 . "./code.cg2js/cg-base.fasl")
(#xd0c6b3cfae0cdb62ac3c02499aa0aba4 . "./code.cg2js/cg-bitmap-pane-clipboard.fasl")
(#xa6ce9f93b5933dad1c957b5b59724c25 . "./code.cg2js/cg-bitmap-pane.fasl")
(#x7c16ab9f3e44c3a6dd69ccddea8413df . "./code.cg2js/cg-bitmap-stream.fasl")
(#x615629a09cce8ea5667109f0dcf54194 . "./code.cg2js/cg-button.fasl")
(#x70156a9bf381aa7846eaa49c5517d0f0 . "./code.cg2js/cg-calendar.fasl")
(#xde3758bc5d15c491ffee1f7bbc7d9158 . "./code.cg2js/cg-caret.fasl")
(#x56cab4604eb89cfc260fa2806d13054e . "./code.cg2js/cg-chart-or-plot.fasl")
(#x3cb463a43bc51e9e7599d56b3c03560a . "./code.cg2js/cg-chart-widget.fasl")
(#xb1a1c61a9518d9f01c8c948aab983a80 . "./code.cg2js/cg-check-box.fasl")
(#xe0d521bfd729407478201d28977d0ae5 . "./code.cg2js/cg-choice-list.fasl")
(#x7cfc04ea567c677f6b27fd61defb02c4 . "./code.cg2js/cg-choose-printer.fasl")
(#x1f2ded22a8c78b64ccf1483b08af4a49 . "./code.cg2js/cg-class-grid.fasl")
(#xcc03631cb7a8b826134b32e5d1983664 . "./code.cg2js/cg-class-slot-grid.fasl")
(#x448037d6227374ca3df8df35ace8bbf4 . "./code.cg2js/cg-class-support.fasl")
(#x1501fd3afe837d9a0ab33ffe4016daf5 . "./code.cg2js/cg-clipboard-pixmap.fasl")
(#x6ebf5bbea34dd18bb8020acfa916b318 . "./code.cg2js/cg-clipboard-stack.fasl")
(#x4afddd1dc32937ebb90f80568885a168 . "./code.cg2js/cg-clipboard.fasl")
(#xe395a86ed7b20596841750104004a028 . "./code.cg2js/cg-color-dialog.fasl")
(#x294ab031f599a9928dc05b40bcc3b6b1 . "./code.cg2js/cg-combo-box.fasl")
(#x522dfd4f28eb036a11aca7ce1fecd954 . "./code.cg2js/cg-common-control.fasl")
(#xf30d945b4f4fce43473ee25d446d9962 . "./code.cg2js/cg-comtab.fasl")
(#x0bd8fba43a3a70e3289a531e3d807841 . "./code.cg2js/cg-cursor-pixmap.fasl")
(#xf7601ec38704ae186a95b98e495bfbd1 . "./code.cg2js/cg-curve.fasl")
(#xf1082edaeafba87738084cfe2c5cd836 . "./code.cg2js/cg-dde-utils.fasl")
(#xa69c2873a4d133fe2fdd502a55cac181 . "./code.cg2js/cg-dev.fasl")
(#x90b12b5c574df3bd5659e1768bbd9f30 . "./code.cg2js/cg-dialog-item.fasl")
(#xd2250ccbb3ce39b1f4c4f5820b626a5b . "./code.cg2js/cg-directory-dialog-os.fasl")
(#x55b31a5a136d6fe115a7f67856fbc6a7 . "./code.cg2js/cg-directory-dialog.fasl")
(#x650f49f7a605534092f1fe0a3a415f59 . "./code.cg2js/cg-drag-and-drop-image.fasl")
(#x74f04a692e3daa9d3ef92848c06387aa . "./code.cg2js/cg-drag-and-drop.fasl")
(#x909d1a0abbc9f7d3974de78c9aa21c81 . "./code.cg2js/cg-drawable-clipboard.fasl")
(#xf2be4bb9a793101d672b081f7860eb19 . "./code.cg2js/cg-drawable.fasl")
(#xf7c645502677dcd3cae5b7e87557924d . "./code.cg2js/cg-dropping-outline.fasl")
(#x151bd325d78a64297cda938ae13ea0cb . "./code.cg2js/cg-edit-in-place.fasl")
(#x4654f6700f655b5a101bd12c7c06c810 . "./code.cg2js/cg-editable-text.fasl")
(#xabb2c1d4dcafa31ef0d1793162cc44a1 . "./code.cg2js/cg-file-dialog.fasl")
(#x27836514caadac560f2c51f062271498 . "./code.cg2js/cg-fill-texture.fasl")
(#x00a0e3e5f5abfd102124e39196678278 . "./code.cg2js/cg-find-string-dialog.fasl")
(#x48aec6844546f34151deaf4e6e83dc5e . "./code.cg2js/cg-font-dialog.fasl")
(#xba0027bff9ffc590b2e251aa82779104 . "./code.cg2js/cg-gesture-emulation.fasl")
(#x171d078c2ac909f8dd46bcadfff70228 . "./code.cg2js/cg-get-pixmap.fasl")
(#xba61d5a6eda8a31a5df7b88de51c8395 . "./code.cg2js/cg-get-position.fasl")
(#x7c39b20e61bcd878189153ef1989ed43 . "./code.cg2js/cg-graphics-context.fasl")
(#x4443e7622b652e9d27b4fcf1a6157360 . "./code.cg2js/cg-grid-widget-drag-and-drop.fasl")
(#x5b534073bb7ae13a6e2acfc2c8e7975f . "./code.cg2js/cg-grid-widget.fasl")
(#xa07edcf376fc29e6d429e6f3d99c4398 . "./code.cg2js/cg-group-box.fasl")
(#x1ce9d8cbe668a6a75ef338ba8ab55d1c . "./code.cg2js/cg-header-control.fasl")
(#x330fcea88eaaca6860fa42fa392155d8 . "./code.cg2js/cg-hotspot.fasl")
(#xebc89124a8a0157bb02db2a359463359 . "./code.cg2js/cg-html-dialog.fasl")
(#x2a438a6c2e66db07d2e5ff76c6f6b060 . "./code.cg2js/cg-html-widget.fasl")
(#xe4802981835c82183d7475e057604d6c . "./code.cg2js/cg-icon-pixmap.fasl")
(#x26d4a068cab47d438a5511e33636854c . "./code.cg2js/cg-icon.fasl")
(#x1db8ac1707d04acd367b516e0f786952 . "./code.cg2js/cg-ie.fasl")
(#xf3c091f1ca170aee266a78d936384c03 . "./code.cg2js/cg-intersect-posbox.fasl")
(#xe379184ffbe181ac6a5b6579658184ff . "./code.cg2js/cg-intersect.fasl")
(#xab178f52a1580b156194e289b9d19f3a . "./code.cg2js/cg-item-list.fasl")
(#x6ac33911dfe2d707ab3faf0e1a04dbd9 . "./code.cg2js/cg-keyboard-shortcuts.fasl")
(#x12b3ca54d15cb2165e5ef498ad6e48e5 . "./code.cg2js/cg-lamp.fasl")
(#xb9d7181ea2339e3d10347075f0497051 . "./code.cg2js/cg-layout.fasl")
(#x20dee1b7a4da6678bb96083da21e04e7 . "./code.cg2js/cg-lettered-menu.fasl")
(#x2387f395f5acc29a23171ac304d09371 . "./code.cg2js/cg-lisp-edit-pane.fasl")
(#xbae19d718e3d95fc2139a6a9a2c6234c . "./code.cg2js/cg-lisp-text.fasl")
(#xeff4640ede13994fbfa72c513e370a13 . "./code.cg2js/cg-lisp-widget.fasl")
(#xea74b22db3f3ebc8d22da2e5c709036e . "./code.cg2js/cg-list-view.fasl")
(#x014c58be75827cae329fef9a73d003f6 . "./code.cg2js/cg-mci.fasl")
(#xe3c0a1d01d8c3c8c4efd891a66c047b1 . "./code.cg2js/cg-menu-tooltip.fasl")
(#x9860734d41d731d5c8a5a562f5ff8731 . "./code.cg2js/cg-menu.fasl")
(#xe649f79f63986593967f806d2450afbf . "./code.cg2js/cg-message-dialog.fasl")
(#x6bb924f3ba670a22ee4940ea78d7c36b . "./code.cg2js/cg-multi-line-editable-text.fasl")
(#xd0a6dd1abd90d5aa8d45def3786c3e66 . "./code.cg2js/cg-multi-line-lisp-text.fasl")
(#x082a4c0aeb6b3ba39527f2a6cebb88e4 . "./code.cg2js/cg-multi-picture-button-drag-and-drop.fasl")
(#x81f271067b5a171bdf8e5ea90840ff4b . "./code.cg2js/cg-multi-picture-button-tooltip.fasl")
(#x8e53e8ab401cd1586f83afac00d34e26 . "./code.cg2js/cg-multi-picture-button.fasl")
(#xd0101d37cc7b945376b64593208d30f4 . "./code.cg2js/cg-nodes.fasl")
(#x1b1d87ca0118ddac5ea3257155d0ad56 . "./code.cg2js/cg-object-editor-layout.fasl")
(#xcf3a6e67aae0e8331c552631b009f063 . "./code.cg2js/cg-object-editor.fasl")
(#x5ca58fced9ee3b67c60d1a8ed5368cbe . "./code.cg2js/cg-ocx.fasl")
(#xe9577818aa3268a5bb5057afbe737131 . "./code.cg2js/cg-os-widget.fasl")
(#xfc24394a8ee02ac817ee2a850ceb8236 . "./code.cg2js/cg-os-window.fasl")
(#xeac8cfd997a09f379f5669d2fbb504e0 . "./code.cg2js/cg-outline-drag-and-drop.fasl")
(#x631952f83741b5bd92ed95885ca84cc7 . "./code.cg2js/cg-outline-edit-in-place.fasl")
(#xe15679c3bd7d1dab64a4656b85fa8337 . "./code.cg2js/cg-outline.fasl")
(#x26c4192cfdf67796c368e94165636c21 . "./code.cg2js/cg-palette.fasl")
(#x71659c6319776d4fb90c403dfb10f2c8 . "./code.cg2js/cg-paren-matching.fasl")
(#xe8739dcd56ad4d944c7162b68bb82f93 . "./code.cg2js/cg-picture-widget-palette.fasl")
(#x6197aa7136b2ee241b4096dbd847980e . "./code.cg2js/cg-picture-widget.fasl")
(#xc587b90e140f20c7ff86e1e23708d252 . "./code.cg2js/cg-pixmap-file-io.fasl")
(#x2221edb99514f023d5839d049794be77 . "./code.cg2js/cg-pixmap-printing.fasl")
(#xd4a60905497d34cc36b57f5178c04dc2 . "./code.cg2js/cg-pixmap-rotate.fasl")
(#xc308ff5308e5013069758a13b5fa8384 . "./code.cg2js/cg-pixmap-widget.fasl")
(#xe29fa628d88de122e53ea3c9d4708dfc . "./code.cg2js/cg-pixmap.fasl")
(#xc142e3c599c932100f1ecf16f9554afb . "./code.cg2js/cg-plot-widget.fasl")
(#x9a90c85440386eae6baae260700cd2ee . "./code.cg2js/cg-printing.fasl")
(#x64685f98d65faf47945bfb170d21373a . "./code.cg2js/cg-progress-indicator.fasl")
(#xdec0208e92e4410d72b0e180843484b8 . "./code.cg2js/cg-project-window.fasl")
(#xf713f81c0600129fef094ccec813419f . "./code.cg2js/cg-property.fasl")
(#x0f6238d16348d2e8f698d5f76c198a52 . "./code.cg2js/cg-radio-button.fasl")
(#x1b8de2174a322678919c0149a219f7f3 . "./code.cg2js/cg-rich-edit-pane-clipboard.fasl")
(#x9ff3a02de6fca76d08cf5c162e5983e7 . "./code.cg2js/cg-rich-edit-pane-printing.fasl")
(#x2ded33a68f61060c44eba88d5e352074 . "./code.cg2js/cg-rich-edit-pane.fasl")
(#x22879f03e2263afea4709ae9fa4cc652 . "./code.cg2js/cg-rich-edit.fasl")
(#xa897c2257833992e71d21ccef181b1af . "./code.cg2js/cg-sample-file-menu.fasl")
(#x2e14a6d7751d4bb70f3053c2ac38419c . "./code.cg2js/cg-scaling-stream.fasl")
(#x21bda051b06239712d049ac1d5f68359 . "./code.cg2js/cg-scroll-bar-mixin.fasl")
(#x948ea671e7033c98cc0da288a59240ac . "./code.cg2js/cg-scroll-bar.fasl")
(#x33cb87252200f4c0140622a171285c63 . "./code.cg2js/cg-scrolling-static-text.fasl")
(#x07cf233a749e32facdd6db813118ae99 . "./code.cg2js/cg-selected-object.fasl")
(#x1a0540d22f70543fed7987edd52f5eff . "./code.cg2js/cg-shortcut-menu.fasl")
(#x3de4df5d4d516d79470775a4433dac86 . "./code.cg2js/cg-split-bar.fasl")
(#x849b2b0f35eb75bc3e315d53f2b14d20 . "./code.cg2js/cg-static-text.fasl")
(#x336e6aa95dd17d596103d05d95a7d843 . "./code.cg2js/cg-status-bar.fasl")
(#xfc266a896f56daa7cb0a4cf4276a6154 . "./code.cg2js/cg-string-dialog.fasl")
(#x261e36c6d05ad6c4859c90be4433f50e . "./code.cg2js/cg-tab-control.fasl")
(#x0904bb0c22b1951c2b7173017641f2af . "./code.cg2js/cg-template-string.fasl")
(#x59a686aca3c9eac2c48dbe29108ea11b . "./code.cg2js/cg-text-edit-pane-file-io.fasl")
(#x40b2ee5f77064d13b02260c0de4d4493 . "./code.cg2js/cg-text-edit-pane-mark.fasl")
(#xa85b63363eab41e4cb322857aa2f8f9d . "./code.cg2js/cg-text-edit-pane.fasl")
(#xeedda07883636974ae8b425b8868f330 . "./code.cg2js/cg-text-or-combo.fasl")
(#xdc05958e2e43ca9f0f8467ec9cb74ace . "./code.cg2js/cg-text-widget.fasl")
(#x74cad1251490c92c36050634d76e306f . "./code.cg2js/cg-timer.fasl")
(#x38dd1e7ac0352fabcd209e3fac67638b . "./code.cg2js/cg-toggling-widget.fasl")
(#xcf1952647ac275b72700a10732592f17 . "./code.cg2js/cg-toolbar.fasl")
(#x807b158b0d130567adf66278be15f9eb . "./code.cg2js/cg-tooltip.fasl")
(#x826234708bebf2b38dccd09860da0a97 . "./code.cg2js/cg-touch.fasl")
(#xa55e60ef3d1fcd93b4c399fabc9ed1e3 . "./code.cg2js/cg-trackbar.fasl")
(#x0fb554d31666a1294ecd6876dcb79af3 . "./code.cg2js/cg-tray.fasl")
(#x3b6383180a8065239e7155036160131b . "./code.cg2js/cg-up-down-control.fasl")
(#xad723a65f880fcf56daabbe3257c3ff3 . "./code.cg2js/cg-utility-dialog.fasl")
(#x73564899887601a0088eca0f1b9af0b5 . "./code.cg2js/cg-web-browser-dde.fasl")
(#xbd6c3007d972acdff515fbb9811666e2 . "./code.cg2js/cg-web-browser.fasl")
(#x8794974b501fad2a1263c072c1270103 . "./code.cg2js/cg-wrap-string.fasl")
(#x9ff7583d7aa42c2d3a12e93a784d74a9 . "./code.cg2js/cg-yes-no-list.fasl")
(#xa7813ae28f54f8f3643de625b19d7388 . "./code.cg2js/cg-yes-no-string.fasl")
(#x6493496c93b5de463e69d1667b01d5d2 . "./code.cg2js/cg.fasl")
(#xd1ee48e2ac65f0b9885a006296128fc1 . "./code.idejs/ide-acache.fasl")
(#xb015c165a048d80fcf263d2f3489c9a1 . "./code.idejs/ide-apropos.fasl")
(#x6a7f0e5df0910a526abb8ef3644454a5 . "./code.idejs/ide-base.fasl")
(#xb25e6550cccd450953256d00d853c843 . "./code.idejs/ide-class-browser.fasl")
(#xfab8fd7e31f28c7a7d10a59310b07ec7 . "./code.idejs/ide-class-grapher.fasl")
(#xb6ba559c09ce42c5806ce9355d723408 . "./code.idejs/ide-clipboard.fasl")
(#x067311abfe85a8da336ffbd16f0b4314 . "./code.idejs/ide-dev.fasl")
(#x871b396719faede0ab8c1a838515f24f . "./code.idejs/ide-editor.fasl")
(#x5a1da942eb652e1237c338f54dc45f2b . "./code.idejs/ide-find-definitions.fasl")
(#x04afd7589ad49dc904607dd3809fdede . "./code.idejs/ide-find-in-files.fasl")
(#x359ff1fad9f007801ef8b4674ce0594e . "./code.idejs/ide-form.fasl")
(#xef92fece9bbe033cd1b38e3b16689d38 . "./code.idejs/ide-grapher.fasl")
(#xa54e32f2dc109a01d7995ee499fa08bd . "./code.idejs/ide-inspector.fasl")
(#x0d00f67803632db52a2c673d0f0e0be0 . "./code.idejs/ide-intro.fasl")
(#x41b90f9e952f97c1668ca651fe7cef2f . "./code.idejs/ide-keyshort.fasl")
(#x21a7ba5a691059a28552bf39355a2252 . "./code.idejs/ide-navigator.fasl")
(#x4c9377a7e1d5bb3ae24908549ee60eaf . "./code.idejs/ide-package-list.fasl")
(#x92ec59a039aa457eb57049da2b4e086c . "./code.idejs/ide-patch-dialog.fasl")
(#xc47bd95831fce4d71a5c9c06a78abea7 . "./code.idejs/ide-process-browser.fasl")
(#x2c0c776092c9d225c1168cf0e3e51cd4 . "./code.idejs/ide-project.fasl")
(#x3d7f23ce87c0e9c563581900dba53024 . "./code.idejs/ide-trace.fasl")
(#x2af65711db74c6d489925a062d316f8e . "./code.idejs/ide-window-list.fasl")
(#x430a64dde73cf2e4ee300ab3a8362cc4 . "./code.idejs/ide.fasl")
(#xea5d13ce0f9a2cfde1ff539415770ab2 . "./cgjs.html")
(#xa0fd27890288fb85b9ee621ed47b2251 . "./ssl-not-found.html")
(#x4e1b21622d7d9cc4e6fc09c7875f8430 . "./browser-not-supported.html"))
 )

(let ((files-ok
       (dolist (checksum *checksums* t)
	 (when (/= (car checksum)
		   (md5-file
		    (merge-pathnames (cdr checksum) *load-pathname*)))
	   (return nil)))))
  (cond
   ((not files-ok)
    (error "The extracted files failed the checksum test.  ~
Please download and/or extract again."))
   (t
    (format t "Checksums on files are OK...~%"))))

;; We have validated all the files are there...

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; check for needed patches

(eval-when (compile eval load) (require :build))

(defvar *required-patches* '(#+macosx ("build" . 3)))

(dolist (required-patch *required-patches*)
  (let ((existing-patch (assoc (car required-patch)
			    (cdr (assoc :system sys::*patches*))
			    :test #'string=)))
    (when (null existing-patch)
      (error "Could not find patch info for the ~s module."
	     (car required-patch)))
    (when (not (>= (second existing-patch) (cdr required-patch)))
      ;; The build patch number is NOT >= to the one we require
      (error "~
Expected version ~d of ~s but have version ~d.  Please update ~
your lisp with update.~a and then do the CG/JS installation again."
	     (cdr required-patch) (car required-patch)
	     (second existing-patch)
	     #+mswindows "exe"
	     #-mswindows "sh"))))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; copy files

(defun copy (source dest)
  (cond
   ((file-directory-p source)
    (format t "Copy directory ~a~%" (enough-namestring source))
    (copy-directory source dest :quiet t))
   (t
    (format t "Copy file ~a~%" (enough-namestring source))
    (sys:copy-file source dest :verbose nil))))

(defvar *sys* (translate-logical-pathname (pathname "sys:")))

(cond
 ((excl::pathname-equalp (truename *sys*)
			 (path-pathname *load-truename*))
  (format t "Files are already in place, no copying requiring.~%"))
 (t ;; copy files, replacing them with new ones if they already exist
  (let (dest)
    (dolist (from *extra-files*)
      (setq dest (merge-pathnames (file-namestring from) *sys*))
      (when (probe-file dest) (delete-file dest))
      (copy from dest))
    
    (dolist (from (list *cg2js-directory* *idejs-directory*))
      (setq dest (merge-pathnames (file-namestring from) *sys*))
      ;; now make it a directory pathname
      (setq dest (pathname-as-directory dest))

      (when (probe-file dest) (delete-directory-and-files dest))
      (copy (pathname-as-directory from) dest)))))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; update develenv.cl to load CG/JS before the original version of CG

(defvar *setup-cgjs-loading* "sys:setup-cgjs-loading.cl")

;; Because users might use an ANSI lisp to install, have to make sure
;; the resulting file can be loaded into an ANSI and Modern lisp.
(with-open-file (s *setup-cgjs-loading* :direction :output
		 :if-exists :supersede)
  (format s "~
;; This file was created by install-cgjs.cl.
;; Please do not edit it.

")
  (dolist (dir (list "code.cg2js/" "code.idejs/"))
    (format s "
(let ((path (make-pathname
	     :type \"fasl\"
	     :directory (pathname-directory
			 (merge-pathnames
			  ~s
			  (translate-logical-pathname \"sys:\"))))))
  (format t \";; *require-search-list*: adding: ~~s~%\" path)
  (push path sys:*require-search-list*))

"
	    dir)))

(defvar *develenv.cl* (pathname "sys:develenv.cl"))

(when (not (probe-file *develenv.cl*))
  (setf (file-contents *develenv.cl*)
    ";; This file is loaded before images are rebuilt with update.sh/update.exe

"))

(let ((contents (file-contents *develenv.cl*)))
  (cond
   ((match-re
     (format nil "^#\\|\\|# \\(load \"sys:~a"
	     (file-namestring *setup-cgjs-loading*))
     contents
     :multiple-lines t)
    (format t "develenv.cl already correctly loads CG/JS.~%"))
   ((match-re
     (format nil "^#\\+ignore \\(load \"sys:~a"
	     (file-namestring *setup-cgjs-loading*))
     contents
     :multiple-lines t)
    (format t "develenv.cl: CG/JS disabled; will enable.~%")
    (setf (file-contents *develenv.cl*)
      (replace-re  contents
		  (format nil "^#\\+ignore *\\(load \"sys:~a"
			  (file-namestring *setup-cgjs-loading*))
		  (format nil "#||# (load \"sys:~a"
			  (file-namestring *setup-cgjs-loading*))
		  :multiple-lines t
		  :count 1)))
   (t
    (format t "develenv.cl: adding CG/JS initialization.~%")
    (setf (file-contents *develenv.cl*)
      (concatenate 'simple-string
	contents
	(format nil "~

;; To disable the use of CG/JS and go back to the originally released
;; (and possibly patched) version of CG/IDE, change the #||# to
;; #+ignore on the following line and the rebuild images by running
;; update.sh or update.exe, depending on your platform:
#||# (load \"sys:~a\")~%~%"
		(file-namestring *setup-cgjs-loading*)))))))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; success!

(let ((msg (format nil "~
CG/JS installation successful!

NOTE: to use CG/JS you must rebuild images by running 'update.~a'
      in the Allegro CL directory (~a)."
		   #+mswindows "exe"
		   #-mswindows "sh"
		   *sys*)))
  #-mswindows (format t "~&~%~a~%" msg)
  #+mswindows (excl::internal-message-box msg "CG/JS Installation" :type :ok))
